@@ -78,7 +78,7 @@ use Sys::Virt::NWFilter;
 use Sys::Virt::DomainSnapshot;
 use Sys::Virt::Stream;
 
-our $VERSION = '2.1.0';
+our $VERSION = '2.2.0';
 require XSLoader;
 XSLoader::load('Sys::Virt', $VERSION);
 
@@ -1616,6 +1616,38 @@ unregistering the event.
 Unregister a callback, associated with the C<$callbackID> previously
 obtained from C<storage_pool_event_register_any>.
 
+=item $callback = $conn->node_device_event_register_any($dev, $eventID, $callback)
+
+Register a callback to received notifications of node device events.
+The C<$dev> parameter can be C<undef> to request events on all
+known node devices, or a specific C<Sys::Virt::NodeDevice> object
+to filter events. The C<$eventID> parameter is one of the EVENT ID
+constants described later in this document. The C<$callback> is
+a subroutine reference that will receive the events.
+
+All callbacks receive a C<Sys::Virt> connection as the first parameter
+and a C<Sys::Virt::NodeDevice> object indicating the node device on
+which the event occurred as the second parameter. Subsequent parameters
+vary according to the event type
+
+=over
+
+=item EVENT_ID_LIFECYCLE
+
+Extra C<event> and C<detail> parameters defining the lifecycle
+transition that occurred.
+
+=back
+
+The return value is a unique callback ID that must be used when
+unregistering the event.
+
+
+=item $conn->node_device_event_deregister_any($callbackID)
+
+Unregister a callback, associated with the C<$callbackID> previously
+obtained from C<node_device_event_register_any>.
+
 =item $conn->register_close_callback($coderef);
 
 Register a callback to be invoked when the connection is closed.
@@ -1717,7 +1749,7 @@ are the free count for that size.
 
 =item $con->node_alloc_pages(\@pages, $start, $end, $flags=0)
 
-Allocate further huge pages for the reserved pool. The <\@pages>
+Allocate further huge pages for the reserved dev. The <\@pages>
 parameter is an array reference with one entry per page size to
 allocate for. Each entry is a further array reference where the
 first element is the page size and the second element is the
